==> jc-1.4.0.tar.gz: gnu/xml/dom/DomEntityReference.h <==
// public class gnu.xml.dom.DomEntityReference

// class file dependencies
// @dep_class 989e53799603f072 gnu_xml_dom_DomEntityReference
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomEntityReference_H_
#define _JC_gnu_xml_dom_DomEntityReference_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEntityReference$sub_refs	_jc_gnu_xml_dom_DomEntityReference$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs	_jc_gnu_xml_dom_DomEntityReference$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$refs	_jc_gnu_xml_dom_DomEntityReference$refs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$nonrefs	_jc_gnu_xml_dom_DomEntityReference$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$object	_jc_gnu_xml_dom_DomEntityReference$object;

typedef const struct _jc_gnu_xml_dom_DomEntityReference$vmethods	_jc_gnu_xml_dom_DomEntityReference$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEntityReference$vtable	_jc_gnu_xml_dom_DomEntityReference$vtable;
typedef const struct _jc_gnu_xml_dom_DomEntityReference$vtype	_jc_gnu_xml_dom_DomEntityReference$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEntityReference$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntityReference$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntityReference$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEntityReference$method_info$getBaseURI$1b139395df599840;
extern _jc_method _jc_gnu_xml_dom_DomEntityReference$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEntityReference$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *);
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomEntityReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomEntityReference$vmethods	gnu_xml_dom_DomEntityReference;
};

// Vtype
struct _jc_gnu_xml_dom_DomEntityReference$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEntityReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntityReference$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntityReference$refs {
    _jc_gnu_xml_dom_DomEntityReference$sub_refs	gnu_xml_dom_DomEntityReference;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntityReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs	gnu_xml_dom_DomEntityReference;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEntityReference$object {
	_jc_gnu_xml_dom_DomEntityReference$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEntityReference$vtype	*vtype;
	_jc_gnu_xml_dom_DomEntityReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEntityReference$vtype _jc_gnu_xml_dom_DomEntityReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEntityReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEntityReference$class_object;

#endif	/* _JC_gnu_xml_dom_DomEntityReference_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomEntityReference.h <==
// public class gnu.xml.dom.DomEntityReference

// class file dependencies
// @dep_class 989e53799603f072 gnu_xml_dom_DomEntityReference
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomEntityReference_H_
#define _JC_gnu_xml_dom_DomEntityReference_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEntityReference$sub_refs	_jc_gnu_xml_dom_DomEntityReference$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs	_jc_gnu_xml_dom_DomEntityReference$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$refs	_jc_gnu_xml_dom_DomEntityReference$refs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$nonrefs	_jc_gnu_xml_dom_DomEntityReference$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntityReference$object	_jc_gnu_xml_dom_DomEntityReference$object;

typedef const struct _jc_gnu_xml_dom_DomEntityReference$vmethods	_jc_gnu_xml_dom_DomEntityReference$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEntityReference$vtable	_jc_gnu_xml_dom_DomEntityReference$vtable;
typedef const struct _jc_gnu_xml_dom_DomEntityReference$vtype	_jc_gnu_xml_dom_DomEntityReference$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEntityReference$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntityReference$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntityReference$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEntityReference$method_info$getBaseURI$1b139395df599840;
extern _jc_method _jc_gnu_xml_dom_DomEntityReference$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEntityReference$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomEntityReference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomEntityReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomEntityReference$vmethods	gnu_xml_dom_DomEntityReference;
};

// Vtype
struct _jc_gnu_xml_dom_DomEntityReference$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEntityReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntityReference$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntityReference$refs {
    _jc_gnu_xml_dom_DomEntityReference$sub_refs	gnu_xml_dom_DomEntityReference;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntityReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomEntityReference$sub_nonrefs	gnu_xml_dom_DomEntityReference;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEntityReference$object {
	_jc_gnu_xml_dom_DomEntityReference$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEntityReference$vtype	*vtype;
	_jc_gnu_xml_dom_DomEntityReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEntityReference$vtype _jc_gnu_xml_dom_DomEntityReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEntityReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEntityReference$class_object;

#endif	/* _JC_gnu_xml_dom_DomEntityReference_H_ */
